hepstats.hypotests.core.confidence\_interval module
===================================================

.. automodule:: hepstats.hypotests.core.confidence_interval
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
